# -*- coding: utf-8 -*-
from . import models
from . import controllers
from . import wizard
from . import reports

# hack
from odoo import tools

_orig_trans_load = tools.trans_load
_orig_trans_load_data = tools.trans_load_data

def trans_load(cr, *args, **kwargs):
    if cr.dbname.startswith('_migrate_'):
        return
    return _orig_trans_load(cr, *args, **kwargs)

def trans_load_data(cr, *args, **kwargs):
    if cr.dbname.startswith('_migrate_'):
        return
    return _orig_trans_load_data(cr, *args, **kwargs)

tools.trans_load = tools.translate.trans_load = trans_load
tools.trans_load_data = tools.translate.trans_load_data = trans_load_data


def _pre_install(env):
    if env.ref("base.module_openerp_enterprise").demo and (
        env.company.chart_template != 'be' or env.company.currency_id != env.ref("base.EUR")
    ):
        us_payroll_mod = env["ir.module.module"].search([('name', '=', 'l10n_us_hr_payroll')])
        if us_payroll_mod:
            # Since odoo/enterprise@7df6e8f2899, US Payroll demo datas enforce main company
            # to be in USD and will crash otherwise, i.e. if installed after this module,
            # as we can't selectively disable demo data simply skip installation of that module
            us_payroll_mods = us_payroll_mod + us_payroll_mod.downstream_dependencies()
            us_payroll_mods.filtered(lambda x: x.state == 'to install').button_install_cancel()

        # remove demo invoices/statements
        moves = env["account.move"].search([('company_id', '=', env.company.id)])
        moves.filtered_domain([('state', '!=', 'draft')]).button_draft()
        moves.unlink()

        # remove demo PoS payments and close open PoS sessions
        pos_payments = env["pos.payment"].search([('company_id', '=', env.company.id)])
        pos_payments.unlink()

        pos_session = env["pos.session"].search([('company_id', '=', env.company.id)])
        pos_session.write({'state': 'closed'})

        # reset main company, set currency EUR, country Belgium and reload the CoA
        env.company.update({
            'currency_id': env.ref("base.EUR"),
            'country_id': env.ref("base.be"),
            'account_fiscal_country_id': env.ref("base.be"),
            'chart_template': False,
        })
        env["account.chart.template"].try_loading("be_comp", env.company, install_demo=True)

        # Setup Apps products default vendor/customer taxes ICPs
        ICP = env["ir.config_parameter"]
        apps_be_purchase_tax = env.ref("account.%d_attn_VAT-IN-V81-21" % env.company.id, False)
        if apps_be_purchase_tax:
            ICP.set_param("openerp_apps.apps_seller_tax", [apps_be_purchase_tax.id])
        apps_be_sale_tax = env.ref("account.%d_attn_VAT-OUT-21-S" % env.company.id, False)
        if apps_be_sale_tax:
            ICP.set_param("openerp_apps.apps_product_tax", [apps_be_sale_tax.id])
